==> apache-camel-3.8.0-src.zip: apache-camel-3.8.0/test-infra/camel-test-infra-redis/src/test/java/org/apache/camel/test/infra/redis/services/RedisServiceFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.infra.redis.services;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public final class RedisServiceFactory {
    private static final Logger LOG = LoggerFactory.getLogger(RedisServiceFactory.class);

    private RedisServiceFactory() {

    }

    public static RedisService createService() {
        String instanceType = System.getProperty("redis.instance.type");

        if (instanceType == null || instanceType.equals("local-redis-container")) {
            return new RedisLocalContainerService();
        }

        if (instanceType.equals("remote")) {
            return new RedisRemoteService();
        }

        LOG.error("The property \"redis.instance.type\" must be one of 'local-redis-container' or 'remote");
        throw new UnsupportedOperationException("Invalid Redis instance type");
    }
}

==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/test-infra/camel-test-infra-redis/src/test/java/org/apache/camel/test/infra/redis/services/RedisServiceFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.infra.redis.services;

import org.apache.camel.test.infra.common.services.SimpleTestServiceBuilder;

public final class RedisServiceFactory {
    private RedisServiceFactory() {

    }

    public static SimpleTestServiceBuilder<RedisService> builder() {
        return new SimpleTestServiceBuilder<>("redis");
    }

    public static RedisService createService() {
        return builder()
                .addLocalMapping(RedisLocalContainerService::new)
                .addRemoteMapping(RedisRemoteService::new)
                .build();
    }

    public static class RedisRemoteService extends RedisRemoteInfraService implements RedisService {
    }

    public static class RedisLocalContainerService extends RedisLocalContainerInfraService implements RedisService {
    }
}
